pychi package
=============

Submodules
----------

pychi.light module
------------------

.. automodule:: pychi.light
   :members:
   :undoc-members:
   :show-inheritance:

pychi.materials module
----------------------

.. automodule:: pychi.materials
   :members:
   :undoc-members:
   :show-inheritance:

pychi.models module
-------------------

.. automodule:: pychi.models
   :members:
   :undoc-members:
   :show-inheritance:

pychi.solvers module
--------------------

.. automodule:: pychi.solvers
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pychi
   :members:
   :undoc-members:
   :show-inheritance:
